@@ -22,6 +22,7 @@
 #include <KAboutData>
 #include <KCMultiDialog>
 #include <KColorSchemeManager>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
 
@@ -56,6 +57,8 @@ int main(int argc, char **argv)
                      i18n("(C) 2016 Aleix Pol Gonzalez"));
     KAboutData::setApplicationData(about);
 
+    KCrash::initialize();
+
 #ifdef Q_OS_WIN
     KColorSchemeManager manager;
     QApplication::setStyle(QStringLiteral("breeze"));
