@@ -4,20 +4,19 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef LOCKDEVICEPLUGIN_H
-#define LOCKDEVICEPLUGIN_H
+#pragma once
 
 #include <QObject>
 
 #include <core/kdeconnectplugin.h>
 
-#include "login1dbusinterface.h"
-#include "propertiesdbusinterface.h"
+#include "generated/systeminterfaces/dbusproperties.h"
+#include "generated/systeminterfaces/login1.h"
 
 #define PACKET_TYPE_LOCK QStringLiteral("kdeconnect.lock")
 #define PACKET_TYPE_LOCK_REQUEST QStringLiteral("kdeconnect.lock.request")
 
-class Q_DECL_EXPORT LockDevicePlugin : public KdeConnectPlugin
+class LockDevicePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.lockdevice")
@@ -25,14 +24,13 @@ class Q_DECL_EXPORT LockDevicePlugin : public KdeConnectPlugin
 
 public:
     explicit LockDevicePlugin(QObject *parent, const QVariantList &args);
-    ~LockDevicePlugin() override;
 
     bool isLocked() const;
     Q_SCRIPTABLE void setLocked(bool);
 
     QString dbusPath() const override;
     void connected() override;
-    bool receivePacket(const NetworkPacket &np) override;
+    void receivePacket(const NetworkPacket &np) override;
 
 Q_SIGNALS:
     Q_SCRIPTABLE void lockedChanged(bool locked);
@@ -46,5 +44,3 @@ private:
     OrgFreedesktopLogin1SessionInterface m_login1Interface;
     OrgFreedesktopDBusPropertiesInterface m_propertiesInterface;
 };
-
-#endif
